Module error

Module error 

The error module, which contains information about different errors and also handles them. The Error struct maintains the errors that occur during execution.

Structs

Error