Module value_kinds

Module value_kinds 

The ValueKinds module, which contains the ValueKind enum. These describe the various values within the program. The ValueKind enum maintains the various values in the language. All of the supported values are in this enum. This makes it easy to expand in the future.

Enums

ValueKind